@@ -1,7 +1,8 @@
 #' Apply a Function over a List or Vector via Futures
 #'
-#' `future_lapply()` implements [base::lapply()] using futures, and
-#' analogously for all the other `future_nnn()` functions.
+#' `future_lapply()` implements [base::lapply()] using futures with perfect
+#' replication of results, regardless of future backend used.
+#' Analogously, this is true for all the other `future_nnn()` functions.
 #' 
 #' @param X  A vector-like object to iterate over.
 #' 
@@ -110,6 +111,9 @@ future_lapply <- function(X, FUN, ..., future.globals = TRUE, future.packages =
   stop_if_not(length(future.scheduling) == 1, !is.na(future.scheduling),
             is.numeric(future.scheduling) || is.logical(future.scheduling))
 
+  ## Coerce to as.list()?
+  if (!is.vector(X) || is.object(X)) X <- as.list(X)
+  
   ## Nothing to do?
   nX <- length(X)
   if (nX == 0) return(list())
