@@ -81,56 +81,6 @@ stopifnot(inherits(res, "simpleError"))
 message("*** import_from() ... DONE")
 
 
-# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-# Random seeds
-# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-message("*** Random seeds ...")
-
-set_random_seed(seed = NULL)
-seed <- get_random_seed()
-stopifnot(is.null(seed))
-
-set_random_seed(seed = 42L)
-seed <- get_random_seed()
-stopifnot(identical(seed, 42L))
-
-res <- tryCatch({
-  seed <- as_lecyer_cmrg_seed(seed = FALSE)
-}, error = identity)
-print(res)
-stopifnot(inherits(res, "simpleError"))
-
-seed <- as_lecyer_cmrg_seed(seed = 42L)
-str(seed)
-set_random_seed(seed = seed)
-stopifnot(identical(get_random_seed(), seed))
-
-seed2 <- as_lecyer_cmrg_seed(seed = TRUE)
-str(seed2)
-stopifnot(identical(seed2, seed))
-
-seed3 <- as_lecyer_cmrg_seed(seed = seed)
-str(seed3)
-stopifnot(identical(seed3, seed))
-
-## Invalid L'Ecuyer seed
-seed_invalid <- seed + 1L
-res <- tryCatch({
-  seed <- as_lecyer_cmrg_seed(seed = seed_invalid)
-}, error = identity)
-print(res)
-stopifnot(inherits(res, "simpleError"))
-
-## Invalid seed
-res <- tryCatch({
-  seed <- as_lecyer_cmrg_seed(seed = 1:2)
-}, error = identity)
-print(res)
-stopifnot(inherits(res, "simpleError"))
-
-message("*** Random seeds ... DONE")
-
-
 message("*** stop_if_not() ...")
 
 stop_if_not(TRUE)
@@ -140,13 +90,25 @@ res <- tryCatch({
 }, error = identity)
 stopifnot(inherits(res, "simpleError"))
 res <- tryCatch({
-  stop_if_not(TRUE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE)
+  stop_if_not(list(TRUE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE))
 }, error = identity)
 stopifnot(inherits(res, "simpleError"))
 
 message("*** stop_if_not() ... DONE")
 
 
+message("*** assert_values2() ...")
+
+assert_values2 <- future.apply:::assert_values2
+assert_values2(nX = 2L, values2 = as.list(1:2))
+res <- tryCatch({
+  assert_values2(nX = 1L, values = as.list(1:2), values2 = as.list(1:2), fcn = "tests", debug = TRUE)
+}, error = identity)
+stopifnot(inherits(res, "simpleError"))
+
+message("*** assert_values2() ... DONE")
+
+
 message("*** utils ... DONE")
 
 source("incl/end.R")
